import 'option.dart';
import 'terminal.dart';

final Terminal _terminal = const Terminal();

class Prompter {
  List _results = [];

  void _askText(String prompt) {
    _terminal.printPrompt(prompt);
    _terminal.printOptions([]);
    String response = _terminal.collectInput();

    _results.add({'prompt': prompt, 'choice': response});
    _terminal.clearScreen();
  }

  void _askBinary(String prompt) {
    _terminal.printPrompt('$prompt (y/n)');
    _terminal.printOptions([]);
    String response = _terminal.collectInput();

    if(response == 'y') {
      _results.add({'prompt': prompt, 'choice': true});
      _terminal.clearScreen();
    } else if(response == 'n') {
      _results.add({'prompt': prompt, 'choice': false});
      _terminal.clearScreen();
    } else {
      _terminal.clearScreen();
      _terminal.printError('Please enter y or n');
      _askBinary(prompt);
    }
  }

  void _askMultiple(String prompt, List<Option> options) {
    _terminal.printPrompt(prompt);
    _terminal.printOptions(options);
    int response = int.parse(_terminal.collectInput());
    
    try {
      _results.add({'prompt': prompt, 'choice': options[response].value});
      _terminal.clearScreen();
    } catch (e) {
      _terminal.clearScreen();
      _terminal.printError('Please Enter a Number Within the Range of 0 - ${options.length - 1}');
      _askMultiple(prompt, options);
    }
  }

  void ask(String prompt, String type, dynamic options) {
    if(type == 'multiple') {
      _askMultiple(prompt, options);
    } else if(type == 'binary') {
      _askBinary(prompt);
    } else if(type == 'text') {
      _askText(prompt);
    } else {
      _terminal.printPrompt('$prompt has Invalid Prompt Type\n\n\n');
    }
  }

  List result() {
    return _results;
  }
}
